@@ -82,7 +82,7 @@ class _Builder:
             (prop_dict, prop_hash) = self.__parse_attribute_value(self.__attributes["properties"])
             if prop_hash is None:
                 prop_hash = prop_dict
-                self.__gui._bind_var(prop_hash)
+                prop_hash = self.__gui._bind_var(prop_hash)
                 if hasattr(self.__gui._bindings(), prop_hash):
                     prop_dict = _getscopeattr(self.__gui, prop_hash)
             if isinstance(prop_dict, _MapDict):
@@ -287,7 +287,7 @@ class _Builder:
                         elt = value
                 else:
                     elt = lov[0]
-                var_type = type(elt).__name__
+                var_type = self.__gui._get_unique_type_adapter(type(elt).__name__)
             if adapter is None:
                 adapter = self.__gui._get_adapter_for_type(var_type)
             if lov_name := self.__hashes.get(var_name):
@@ -307,7 +307,8 @@ class _Builder:
             if len(lov) > 0:
                 for elt in lov:
                     ret = self.__gui._run_adapter(
-                        t.cast(t.Callable, adapter), elt, adapter.__name__ if callable(adapter) else "adapter")  # type: ignore
+                        t.cast(t.Callable, adapter), elt, adapter.__name__ if callable(adapter) else "adapter"
+                    )  # type: ignore
                     if ret is not None:
                         ret_list.append(ret)
             self.__attributes[f"default_{property_name}"] = ret_list
@@ -317,7 +318,8 @@ class _Builder:
             val_list = value if isinstance(value, list) else [value]
             for val in val_list:
                 ret = self.__gui._run_adapter(
-                    t.cast(t.Callable, adapter), val, adapter.__name__ if callable(adapter) else "adapter", id_only=True)  # type: ignore
+                    t.cast(t.Callable, adapter), val, adapter.__name__ if callable(adapter) else "adapter", id_only=True
+                )  # type: ignore
                 if ret is not None:
                     ret_list.append(ret)
             if multi_selection:
@@ -411,26 +413,32 @@ class _Builder:
 
     def get_chart_config(self, default_type="scatter", default_mode="lines+markers"):
         names = (
-            "x",
+            "x",  # 0
             "y",
-            "z",
+            "z",  # 2
             "label",
-            "text",
+            "text",  # 4
             "mode",
-            "type",
+            "type",  # 6
             "color",
-            "xaxis",
+            "xaxis",  # 8
             "yaxis",
-            "selected_color",
+            "selected_color",  # 10
             "marker",
-            "selected_marker",
+            "selected_marker",  # 12
             "orientation",
-            "name",
+            "name",  # 14
             "line",
-            "text_anchor",
+            "text_anchor",  # 16
             "options",
+            "lon",  # 18
+            "lat",
         )
         trace = self.__get_multiple_indexed_attributes(names)
+        if not trace[0] and trace[18]:
+            trace[0] = trace[18]  # substitute Lon to x
+        if not trace[1] and trace[19]:
+            trace[1] = trace[19]  # substitute Lat to y
         if not trace[5]:
             # mode
             trace[5] = default_mode
@@ -447,6 +455,10 @@ class _Builder:
         indexed_trace = self.__get_multiple_indexed_attributes(names, idx)
         if len([x for x in indexed_trace if x]):
             while len([x for x in indexed_trace if x]):
+                if not indexed_trace[0] and indexed_trace[18]:
+                    indexed_trace[0] = indexed_trace[18]  # substitute Lon to x
+                if not indexed_trace[1] and indexed_trace[19]:
+                    indexed_trace[1] = indexed_trace[19]  # substitute Lat to y
                 self.__check_dict(indexed_trace, (11, 12, 17), names)
                 traces.append([x or trace[i] for i, x in enumerate(indexed_trace)])
                 idx += 1
@@ -467,7 +479,20 @@ class _Builder:
         columns = set()
         for trace in traces:
             columns.update([t for t in trace[:5] if t])
-        columns = _get_columns_dict(data, list(columns), col_types)
+        # add optionnal column if any
+        markers = [t[11] or ({"color": t[7]} if t[7] else None) for t in traces]
+        opt_cols = set()
+        for m in markers:
+            if isinstance(m, (dict, _MapDict)):
+                color = m.get("color")
+                if isinstance(color, str) and color not in columns:
+                    opt_cols.add(color)
+                size = m.get("size")
+                if isinstance(size, str) and size not in columns:
+                    opt_cols.add(size)
+
+        # Validate the column names
+        columns = _get_columns_dict(data, list(columns), col_types, opt_columns=opt_cols)
         # set default columns if not defined
         icols = [[c for c in [_get_col_from_indexed(c, i) for c in columns.keys()] if c] for i in range(len(traces))]
 
@@ -489,7 +514,7 @@ class _Builder:
                 "types": [t[6] for t in traces],
                 "xaxis": [t[8] for t in traces],
                 "yaxis": [t[9] for t in traces],
-                "markers": [t[11] or ({"color": t[7]} if t[7] else None) for t in traces],
+                "markers": markers,
                 "selectedMarkers": [t[12] or ({"color": t[10]} if t[10] else None) for t in traces],
                 "traces": [[reverse_cols.get(c, c) for c in [t[0], t[1], t[2]]] for t in traces],
                 "orientations": [t[13] for t in traces],
@@ -521,7 +546,9 @@ class _Builder:
                 self.__set_string_attribute(var_name, default_value)
         return self
 
-    def __set_list_attribute(self, name: str, hash_name: t.Optional[str], val: t.Any, elt_type: t.Type, dynamic=True) -> t.List[str]:
+    def __set_list_attribute(
+        self, name: str, hash_name: t.Optional[str], val: t.Any, elt_type: t.Type, dynamic=True
+    ) -> t.List[str]:
         if not hash_name and isinstance(val, str):
             val = [elt_type(t.strip()) for t in val.split(";")]
         if isinstance(val, list):
@@ -577,7 +604,7 @@ class _Builder:
 
     def __set_class_names(self):
         classes = ["taipy-" + self.__control_type.replace("_", "-")]
-        if cl := self.__attributes.get("classname"):
+        if cl := self.__attributes.get("class_name"):
             classes.append(str(cl))
 
         return self.set_attribute("className", " ".join(classes))
@@ -671,6 +698,9 @@ class _Builder:
     def __set_update_var_name(self, hash_name: str):
         return self.set_attribute("updateVarName", hash_name)
 
+    def set_change_delay(self):
+        return self.__set_number_attribute("change_delay", self.__gui._get_config("change_delay", None))
+
     def set_value_and_default(
         self,
         var_name: t.Optional[str] = None,
@@ -760,10 +790,10 @@ class _Builder:
             warnings.warn(f"{self.__element_name} page_size_options should be a list")
         return self
 
-    def set_type(self, type_name: str):
-        self.type_name = type_name
-        self.set_attribute("type", type_name)
-        return self
+    def set_input_type(self, type_name: str, allow_password=False):
+        if allow_password and self.__get_boolean_attribute("password", False):
+            return self.set_attribute("type", "password")
+        return self.set_attribute("type", type_name)
 
     def set_kind(self):
         theme = self.__attributes.get("theme", False)
@@ -817,8 +847,9 @@ class _Builder:
                     attr[0], _get_tuple_val(attr, 2, None), _get_tuple_val(attr, 3, False)
                 )
             elif var_type == _AttributeType.string_list:
-                self.__set_list_attribute(attr[0], self.__hashes.get(
-                    attr[0]), self.__attributes.get(attr[0]), str, False)
+                self.__set_list_attribute(
+                    attr[0], self.__hashes.get(attr[0]), self.__attributes.get(attr[0]), str, False
+                )
             elif var_type == _AttributeType.function:
                 self.__set_function_attribute(attr[0], _get_tuple_val(attr, 2, None), _get_tuple_val(attr, 3, True))
             elif var_type == _AttributeType.react:
