@@ -17,14 +17,19 @@ from ._attributes import (
     _setscopeattr,
     _setscopeattr_drill,
 )
+from ._locals_context import _LocalsContext
 from ._map_dict import _MapDict
+from ._variable_directory import _variable_decode, _variable_encode, _VariableDirectory
 from .boolean import _is_boolean, _is_boolean_true
 from .clientvarname import _get_client_var_name
 from .datatype import _get_data_type
 from .date import _date_to_ISO, _ISO_to_date
 from .expr_var_name import _get_expr_var_name
 from .filename import _get_non_existent_file_path
-from .getdatecolstrname import _get_date_col_str_name
+from .filter_locals import _filter_locals
+from .get_imported_var import _get_imported_var
+from .get_module_name import _get_module_name_from_frame, _get_module_name_from_imported_var
+from .getdatecolstrname import _RE_PD_TYPE, _get_date_col_str_name
 from .isnotebook import _is_in_notebook
 from .killable_thread import _KillableThread
 from .types import (
